@@ -32,12 +32,12 @@ TOPICWORDS = [{"token": "no", "tokenType": "negation"},{"token": "negative", "to
 {"token": "wasn(\'?)t", "tokenType": "negation"},{"token": "weren(\'?)t", "tokenType": "negation"},
 {"token": "won(\'?)t", "tokenType": "negation"},{"token": "don(\'?)t", "tokenType": "negation"},
 {"token": "wouldn(\'?)t", "tokenType": "negation"},{"token": "denies", "tokenType": "negation"},
-{"token": "denied", "tokenType": "negation"},{"token": "\d+\.\d+", "tokenType": "numeric"},
-{"token": "\d+", "tokenType": "numeric"},{"token": "\d+\.\d+", "tokenType": "numeric", "suffix": "[^\s\d-]+"},
-{"token": "\d+", "tokenType": "numeric","suffix": "[^\s\d-]+"},{"token": "one", "tokenType": "numeric"},
-{"token": "two", "tokenType": "numeric"},{"token": "three", "tokenType": "numeric"},
-{"token": "four", "tokenType": "numeric"},{"token": "will", "tokenType": "future"},
-"reveal", "revealed","(\w("+punc+")?){1,2}\w"]
+{"token": "denied", "tokenType": "negation"},{"token": "\d+\.\d+", "tokenType": "numeric", "suffix": "[^\s\d-]+"},
+{"token": "\d+", "tokenType": "numeric","suffix": "[^\s\d-]+"},"([A-Za-z]("+punc+")?){1,2}[A-Za-z]",
+{"token": "\d+\.\d+", "tokenType": "numeric"},{"token": "\d+", "tokenType": "numeric"},
+{"token": "one", "tokenType": "numeric"},{"token": "two", "tokenType": "numeric"},
+{"token": "three", "tokenType": "numeric"},{"token": "four", "tokenType": "numeric"},
+{"token": "will", "tokenType": "future"}, "reveal", "revealed"]
 
 JOINERWORDS = ["of", "in", "to", "on","than","at"]
 
